@@ -2,18 +2,17 @@ import requests
 from ping.helper.apiHelper import json_deserialize, check_errors
 
 
-def get_merchants(headers, base_url):
-    #Does a GET request to /api/v1/merchants.
+def list(headers, base_url):
+    # Does a GET request to /api/v1/merchants.
 
-    #Lists merchants associated with a tenant. The merchant details
-    #include email, id, name, organization number and phone number.
+    # Lists merchants associated with a tenant. The merchant details
+    # include email, id, name, organization number and phone number.
 
-    #Args:
+    # Args:
     #    None arguments.
-    #Returns:
+    # Returns:
     #    Response: A json object with the response value as well as other
-    #    useful information such as status codes, headers and a potention error.
-    
+    #    useful information such as status codes, headers and a potential errors.
 
     # Prepare and execute response
     _path = '/api/v1/merchants'
@@ -26,7 +25,7 @@ def get_merchants(headers, base_url):
     return _result
 
 
-def create_new_merchant(headers, base_url, merchant_object):
+def create(headers, base_url, merchant_object):
     # Does a POST request to /api/v1/merchants.
 
     # Creates a new merchants for a tenant.
@@ -37,8 +36,7 @@ def create_new_merchant(headers, base_url, merchant_object):
     #   merchant_object (object, required): An object containing required merchant data.
     # Returns:
     #    Response: A json object with the response value as well as other
-    #    useful information such as status codes, headers and a potention error.
-    
+    #    useful information such as status codes, headers and a potential errors.
 
     # Prepare and execute response
     _path = '/api/v1/merchants'
@@ -51,18 +49,17 @@ def create_new_merchant(headers, base_url, merchant_object):
     return _result
 
 
-def get_specific_merchant(headers, base_url, merchant_id):
+def get(headers, base_url, merchant_id):
     # Does a GET request to /api/v1/merchants/{merchant_id}.
 
     # Provides details for a single merchant. The details include email, id,
-    #name, organization name, organization number, phone number and status.
+    # name, organization name, organization number, phone number and status.
 
     # Args:
-    #    merchant_id (string, required). The ID of the of the merchant to retrive.
+    #    merchant_id (string, required). The ID of the of the merchant to retrieve.
     # Returns:
     #    Response: A json object with the response value as well as other
-    #    useful information such as status codes, headers and a potention error.
-    
+    #    useful information such as status codes, headers and a potential errors.
 
     # Prepare and execute response
     _path = f'/api/v1/merchants/{merchant_id}'
